@@ -103,6 +103,7 @@ pub struct Lexer<'a, I: Input> {
 
     pub(crate) ctx: Context,
     input: I,
+    start_pos: BytePos,
 
     state: State,
     pub(crate) syntax: Syntax,
@@ -123,12 +124,15 @@ impl<'a, I: Input> Lexer<'a, I> {
         input: I,
         comments: Option<&'a dyn Comments>,
     ) -> Self {
+        let start_pos = input.last_pos();
+
         Lexer {
             comments,
             comments_buffer: comments.is_some().then(CommentsBuffer::new),
             ctx: Default::default(),
             input,
-            state: State::new(syntax),
+            start_pos,
+            state: State::new(syntax, start_pos),
             syntax,
             target,
             errors: Default::default(),
@@ -526,7 +530,7 @@ impl<'a, I: Input> Lexer<'a, I> {
 
             // read hexadecimal escape sequences
             'x' => {
-                raw.push_str("0x");
+                raw.push_str("x");
                 self.bump(); // 'x'
                 return self.read_hex_char(start, 2, raw).map(Some);
             }
